@@ -16,14 +16,11 @@ class BindPoolExecutor:
         @args: None
         @return: None
     """
-    def __init__(self):
-        self.semaphore = None 
-    
     def acquire(self):
         self.semaphore.acquire()
     
     def release(self, fn):
-        self.semaphore.release(fn)
+        self.semaphore.release()
     
     def submit(self, fn, *args, **kwargs):
         self.acquire()
